@@ -37,10 +37,12 @@ if PY3:
         finally:
             traceback = None
 
-    code_obj_args = ['argcount', 'kwonlyargcount', 'nlocals', 'stacksize',
+    code_obj_args = ['argcount', 'posonlyargcount', 'kwonlyargcount', 'nlocals', 'stacksize',
                      'flags', 'code', 'consts', 'names', 'varnames',
                      'filename', 'name', 'firstlineno', 'lnotab', 'freevars',
                      'cellvars']
+    if not PY38:
+        code_obj_args.remove("posonlyargcount")
 else:
     def raise_from(value, from_value=None):
         raise value
